/*
 * File......: BITCLR.PRG
 * Author....: Forest Belt, Computer Diagnostic Services, Inc.
 * Date......: $Date:   02 Apr 1991 18:22:10  $
 * Revision..: $Revision:   1.0  $
 * Log file..: $Logfile:   E:/nanfor/src/bitclr.prv  $
 * 
 * This is an original work by Forest Belt and is placed in the
 * public domain.
 *
 * Modification history:
 * ---------------------
 *
 * $Log:   E:/nanfor/src/bitclr.prv  $
*  
*     Rev 1.0   02 Apr 1991 18:22:10   GLENN
*  Nanforum Toolkit
 *
 */


/*  $DOC$
 *  $FUNCNAME$
 *     FT_BITCLR()
 *  $CATEGORY$
 *     String
 *  $ONELINER$
 *     Clear (reset) selected bit in a byte
 *  $SYNTAX$
 *     FT_BITCLR(cByte, nBitpos) -> cByte
 *  $ARGUMENTS$
 *     <cByte> is a character from CHR(0) to CHR(255).
 *
 *     <nBitpos> is a number from 0 to 7 conforming to standard
 *     right-to-left bit numbering convention and representing the
 *     position of the bit within the byte.
 *  $RETURNS$
 *     Returns new byte, with designated bit cleared (reset).
 *     If parameters are faulty, returns NIL.
 *  $DESCRIPTION$
 *     In effect, ANDs argument byte with a byte that has all bits set except
 *     the target bit.  If bit is already clear (0), it remains clear.
 *     Note: Calls FT_BIT_TEST() in this module.
 *  $EXAMPLES$
 *     This code would clear bit 4 in a byte represented by chr(115):
 *
 *       cNewbyte := FT_BITCLR( CHR(115), 4 )
 *       ? ASC( cNewbyte )         // result: 99
 *       ? cNewbyte                // result: 'c'
 *
 *     This code would clear bit 5 in the byte represented by letter 'A':
 *
 *       FT_BITSET( 'A', 5 )       // result: 'A', since
 *                                 // bit 5 already clear
 *  $END$
 */

FUNCTION FT_BITCLR(cInbyte, nBitpos)

  LOCAL xbyte

  IF valtype(cInbyte) != "C" .or. valtype(nBitpos) != "N"  // parameter check
     xByte := NIL
  ELSE
     IF (nBitPos > 7) .or. (nBitPos < 0) .or. (nBitPos != int(nBitPos))
        xByte := NIL
     ELSE
        xByte := iif( .not. FT_ISBIT(cInByte, nBitpos), cInByte, ;
                             chr(asc(cInByte) - (2 ^ nBitpos)))
     ENDIF
  ENDIF

RETURN xByte

