/*
 * File......: BYTENEG.PRG
 * Author....: Forest Belt, Computer Diagnostic Services, Inc.
 * Date......: $Date:   02 Apr 1991 18:22:22  $
 * Revision..: $Revision:   1.0  $
 * Log file..: $Logfile:   E:/nanfor/src/byteneg.prv  $
 * 
 * This is an original work by Forest Belt and is placed in the
 * public domain.
 *
 * Modification history:
 * ---------------------
 *
 * $Log:   E:/nanfor/src/byteneg.prv  $
*  
*     Rev 1.0   02 Apr 1991 18:22:22   GLENN
*  Nanforum Toolkit
 *
 */


/*  $DOC$
 *  $FUNCNAME$
 *     FT_BYTENEG()
 *  $CATEGORY$
 *     String
 *  $ONELINER$
 *     Perform negation on an ASCII character
 *  $SYNTAX$
 *     FT_BYTENEG(cByte) -> cByte
 *  $ARGUMENTS$
 *     cByte is a character from chr(0) to chr(255).
 *     May be passed in chr() form, as character literal, or
 *     as expression evaluating to chr() value.
 *  $RETURNS$
 *     Returns resulting byte, in chr() form.  If parameters are faulty,
 *     returns NIL.
 *  $DESCRIPTION$
 *     Can be used for bitwise byte manipulation.  In effect, this is a
 *     bit-by-bit (bitwise) NEG operation.  Equivalent to NEG assembler
 *     instruction.
 *  $EXAMPLES$
 *     This code performs a bitwise NEG on byte represented by chr(32):
 *
 *          cNewbyte := FT_BYTENOT(chr(32))
 *          ? asc(cNewbyte)     // result: 224
 *  $END$
 */


FUNCTION FT_BYTENEG(cByte)
RETURN   iif(valtype(cByte) != "C", NIL, chr((256 - asc(cByte)) % 256))

