/*
 * File......: BYTEOR.PRG
 * Author....: Forest Belt, Computer Diagnostic Services, Inc.
 * CIS ID....:
 * Date......: $Date:   02 Apr 1991 18:22:24  $
 * Revision..: $Revision:   1.0  $
 * Log file..: $Logfile:   E:/nanfor/src/byteor.prv  $
 * 
 * This is an original work by Forest Belt and is placed in the
 * public domain.
 *
 * Modification history:
 * ---------------------
 *
 * $Log:   E:/nanfor/src/byteor.prv  $
*  
*     Rev 1.0   02 Apr 1991 18:22:24   GLENN
*  Nanforum Toolkit
 *
 */


/*  $DOC$
 *  $FUNCNAME$
 *     FT_BYTEOR()
 *  $CATEGORY$
 *     String
 *  $ONELINER$
 *     OR any two ASCII characters
 *  $SYNTAX$
 *     FT_BYTEOR(cByte1,cByte2) -> cByte
 *  $ARGUMENTS$
 *     <cByte1> and <cByte2> are characters from CHR(0) TO CHR(255).
 *     May be passed in CHR() form, as character literals, or as
 *     expressions evaluating to CHR() values.
 *  $RETURNS$
 *     Returns resulting byte, in CHR() form.  If parameters are faulty,
 *     returns NIL.
 *  $DESCRIPTION$
 *     Can be used for bitwise byte manipulation.  In effect, this is a
 *     bit-by-bit (bitwise) OR operation.  Equivalent to OR assembler
 *     instruction.
 *  $EXAMPLES$
 *          This code performs a bitwise OR on two bytes represented
 *          by CHR(20) and CHR(10):
 *
 *          cNewbyte := FT_BYTEOR( CHR(20), CHR(10) )
 *          ? ASC( cNewbyte )  // result: 30
 *          ? cNewbyte         // result: non-printing character
 *  $END$
 */

FUNCTION FT_BYTEOR(cByte1, cByte2)

  LOCAL nCounter, xByte

  IF valtype(cByte1) != "C" .or. valtype(cByte2) != "C" // parameter check
     xByte := NIL
  ELSE
     xByte := chr(0)
     for nCounter := 0 to 7           // test each bit position
        if FT_ISBIT(cByte1, nCounter) .or. FT_ISBIT(cByte2, nCounter)
           xByte := FT_BITSET(xByte, nCounter)
        endif
     next
  ENDIF

RETURN xByte

