/*
 * File......: PAGE.PRG
 * Author....: Glenn Scott
 * Date......: $Date:   02 Apr 1991 18:23:44  $
 * Revision..: $Revision:   1.0  $
 * Log file..: $Logfile:   E:/nanfor/src/page.prv  $
 * 
 * This is an original work by Glenn Scott and is placed in the
 * public domain.
 *
 * Modification history:
 * ---------------------
 *
 * $Log:   E:/nanfor/src/page.prv  $
*  
*     Rev 1.0   02 Apr 1991 18:23:44   GLENN
*  Nanforum Toolkit
 *
 */

#include "FTINT86.CH"

#define VIDEO      16

/*  $DOC$
 *  $FUNCNAME$
 *     FT_SETVPG()
 *  $CATEGORY$
 *     Video
 *  $ONELINER$
 *     Set the current video page
 *  $SYNTAX$
 *     FT_SETVPG( <nPage> ) -> NIL
 *  $ARGUMENTS$
 *     <nMode> is a valid video page.
 *  $RETURNS$
 *     NIL
 *  $DESCRIPTION$
 *     Selects the video page.
 *
 *     For more information on graphics programming and video pages, 
 *     consult a reference such as "Programmer's Guide to PC and PS/2
 *     Video Systems" (Microsoft Press).
 *
 *  $EXAMPLES$
 *     // The following sets the current video page to 1
 *
 *     FT_SETVPAGE( 1 )
 *  $END$
 */


FUNCTION FT_SETVPG( nPage )
  LOCAL aRegs[ INT86_MAX_REGS ]

  aRegs[ AX ] = MAKEHI( 5 ) + nPage
  FT_INT86( VIDEO, aRegs )

  RETURN( NIL )



/*  $DOC$
 *  $FUNCNAME$
 *     FT_GETVPG()
 *  $CATEGORY$
 *     Video
 *  $ONELINER$
 *     Get the currently selected video page
 *  $SYNTAX$
 *     FT_GETVPG() -> <nPage>
 *  $ARGUMENTS$
 *     None.
 *  $RETURNS$
 *     The video page, as a numeric.
 *  $DESCRIPTION$
 *     Get the currently selected video page
 *
 *     For more information on graphics programming and video pages, 
 *     consult a reference such as _Programmer's Guide to PC and PS/2
 *     Video Systems_ (Microsoft Press).
 *
 *  $EXAMPLES$
 *     nPage := FT_GETVPG()
 *  $END$
 */



FUNCTION FT_GETVPG()
  LOCAL aRegs[ INT86_MAX_REGS ]

  aRegs[ AX ] := MAKEHI( 15 )
  FT_INT86( VIDEO, aRegs )

  RETURN ( HIGHBYTE( aRegs[ BX ] ) )


