/*
 * File......: SETDATE.PRG
 * Author....: Glenn Scott
 * Date......: $Date:   02 Apr 1991 18:24:06  $
 * Revision..: $Revision:   1.0  $
 * Log file..: $Logfile:   E:/nanfor/src/setdate.prv  $
 * 
 * This is an original work by Glenn Scott and is placed in the
 * public domain.
 *
 * Modification history:
 * ---------------------
 *
 * $Log:   E:/nanfor/src/setdate.prv  $
*  
*     Rev 1.0   02 Apr 1991 18:24:06   GLENN
*  Nanforum Toolkit
 *
 */


/*  $DOC$
 *  $FUNCNAME$
 *     FT_SETDATE()
 *  $CATEGORY$
 *     DOS/BIOS
 *  $ONELINER$
 *     Set the DOS system date
 *  $SYNTAX$
 *     FT_SETDATE( <dDate> ) -> <nResult>
 *  $ARGUMENTS$
 *     <dDate> is a Clipper date variable that you want to set the current
 *     DOS system date to.
 *
 *     It is up to you to send in a valid date.  The 
 *     year must be within the range 1980 through 2099.
 *
 *  $RETURNS$
 *     <nResult> is simply the result of FT_INT86(), passed back
 *     to your program.  
 *
 *  $DESCRIPTION$
 *     FT_SETDATE() uses NANFOR.LIB's FT_INT86() function to use invoke
 *     the DOS Set Date service (Interrupt 33, service 43).  
 *     
 *  $EXAMPLES$
 *
 *  The following program takes a date from the command line and sets
 *  the DOS system date:
 *
 *   FUNCTION main( cDate )
 *
 *      cDate := iif( cDate == nil, dtoc( date() ), cDate )
 *      QOut( "Setting date to: " + cDate  + "... " )
 *      FT_SETDATE( ctod( cDate ) )
 *      Qout( "Today is now: " + dtoc( date() ) )
 *
 *   RETURN ( nil )
 *
 *  $END$
 */

#include "FTINT86.CH"

#define DOS        33
#define SETDATE    43


#ifdef FT_TEST
  FUNCTION MAIN( cDate )

     cDate := iif( cDate == nil, dtoc( date() ), cDate )     
     QOut( "Setting date to: " + cDate  + "... " )
     FT_SETDATE( ctod( cDate ) )
     Qout( "Today is now: " + dtoc( date() ) )

  return ( nil )
#endif

function FT_SETDATE( dDate )
  local aRegs[ INT86_MAX_REGS]

  dDate := iif( valtype(dDate) != "D", date(), dDate )

  aRegs[ AX ] = SETDATE * ( 2 ^ 8 )
  aregs[ CX ] = year( dDate )
  aregs[ DX ] = ( month( dDate ) * ( 2 ^ 8 ) )  + day( dDate )

return( FT_INT86( DOS, aRegs ) )
