/*
 * File......: YEAR.PRG
 * Author....: Jo W. French dba Practical Computing
 * CIS_ID....: 74731,1751
 * Date......: $Date:   02 Apr 1991 18:24:32  $
 * Revision..: $Revision:   1.0  $
 * Log file..: $Logfile:   E:/nanfor/src/year.prv  $
 * 
 * The functions contained herein are the original work of Jo W. French
 * and are placed in the public domain.
 *
 * Modification history:
 * ---------------------
 *
 * $Log:   E:/nanfor/src/year.prv  $
*  
*     Rev 1.0   02 Apr 1991 18:24:32   GLENN
*  Nanforum Toolkit
 *
 */

/*  $DOC$
 *  $FUNCNAME$
 *     FT_YEAR()
 *  $CATEGORY$
 *     Date/Time
 *  $ONELINER$
 *     Returns calendar or fiscal year data
 *  $SYNTAX$
 *     FT_YEAR( [<dGivenDate>] ) -> aDateInfo
 *  $ARGUMENTS$
 *     <dGivenDate> is any valid date in any date format.  Defaults
 *     to current system date if not supplied.
 *  $RETURNS$
 *     A three element array containing the following data:
 *
 *        aDateInfo[1] - The year as a character string "YYYY"
 *        aDateInfo[2] - The beginning date of the year
 *        aDateInfo[3] - The ending date of the year
 *  $DESCRIPTION$
 *     FT_YEAR() returns an array containing data about the week
 *     containing the given date.
 *
 *     Normally the return data will be based on a year beginning
 *     on January 1st with weeks beginning on Sunday.
 *
 *     The beginning of year date and/or beginning of week day can be
 *     changed by using FT_DATECNFG(), which will affect all subsequent
 *     calls to FT_YEAR() until another call to FT_DATECNFG().
 *
 *     The beginning of year date and beginning of week day may be reset
 *     to January 1 and Sunday by calling FT_DATECNFG() with no
 *     parameters.
 *  $EXAMPLES$
 *     // get info about year containing 9/15/90
 *     aDateInfo := FT_YEAR( Ctod("09/15/90") )
 *     ? aDateInfo[1]   //  1990
 *     ? aDateInfo[2]   //  09/09/90     beginning of year
 *     ? aDateInfo[3]   //  09/15/90     end of year
 *
 *     // get info about current year
 *     aDateInfo := FT_YEAR()
 *     ? aDateInfo[1]   //  1991
 *     ? aDateInfo[2]   //  06/16/91   beginning of year
 *     ? aDateInfo[3]   //  06/22/91   end of year
 *  $SEEALSO$
 *     FT_DATECNFG() FT_WEEK() FT_MONTH() FT_QTR()
 *  $END$
*/

FUNCTION FT_YEAR(dGivenDate)

  LOCAL aRetVal[3], aTemp, cFY_Start
  LOCAL cDateFormat := SET(_SET_DATEFORMAT)

  aTemp := FT_DATECNFG()
  cFY_Start := aTemp[1]
  SET(_SET_DATEFORMAT, "yyyy.mm.dd")
  dGivenDate := IF(dGivenDate == NIL .OR. VALTYPE(dGivenDate) != 'D',;
                    DATE(), dGivenDate)
  aRetVal[2] := CTOD(STR( YEAR(dGivenDate) - IF(MONTH(dGivenDate) < ;
                    MONTH(CTOD(cFY_Start)), 1, 0), 4) + ;
                    SUBSTR(cFY_Start, 5, 6) )
  aRetval[3] := FT_MADD(aRetVal[2], 12) - 1
  aRetVal[1] := STR(YEAR(aRetVal[3]),4)      // End of Year
  SET(_SET_DATEFORMAT, cDateFormat)

RETURN aRetVal

